# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tsetsen_tts.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'tsetsen_tts.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11tsetsen_tts.proto\x12\x0etsetsen.api.v1\"I\n\x11ListVoicesRequest\x12\x0f\n\x07\x61pi_key\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x12\n\nskip_cache\x18\x03 \x01(\x08\"\xae\x01\n\x05Voice\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12,\n\x06gender\x18\x03 \x01(\x0e\x32\x1c.tsetsen.api.v1.Voice.Gender\x12\x10\n\x08language\x18\x04 \x01(\t\x12\x13\n\x0bpreview_url\x18\x05 \x01(\t\"6\n\x06Gender\x12\x16\n\x12GENDER_UNSPECIFIED\x10\x00\x12\x08\n\x04MALE\x10\x01\x12\n\n\x06\x46\x45MALE\x10\x02\";\n\x12ListVoicesResponse\x12%\n\x06voices\x18\x01 \x03(\x0b\x32\x15.tsetsen.api.v1.Voice\"h\n\x15GenerateSpeechRequest\x12\x0f\n\x07\x61pi_key\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x10\n\x08voice_id\x18\x03 \x01(\t\x12\r\n\x05speed\x18\x04 \x01(\x02\x12\x0f\n\x07version\x18\x05 \x01(\t\"\xc5\x01\n\x16GenerateSpeechResponse\x12\x12\n\nrequest_id\x18\x01 \x01(\t\x12=\n\x06status\x18\x02 \x01(\x0e\x32-.tsetsen.api.v1.GenerateSpeechResponse.Status\"X\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\x0e\n\nPROCESSING\x10\x02\x12\r\n\tCOMPLETED\x10\x03\x12\n\n\x06\x46\x41ILED\x10\x04\"9\n\x12\x43heckStatusRequest\x12\x0f\n\x07\x61pi_key\x18\x01 \x01(\t\x12\x12\n\nrequest_id\x18\x02 \x01(\t\"\xb9\x03\n\x13\x43heckStatusResponse\x12\x12\n\nrequest_id\x18\x01 \x01(\t\x12:\n\x06status\x18\x02 \x01(\x0e\x32*.tsetsen.api.v1.CheckStatusResponse.Status\x12\x11\n\taudio_url\x18\x03 \x01(\t\x12\x15\n\rerror_message\x18\x04 \x01(\t\x12<\n\x07metrics\x18\x05 \x01(\x0b\x32+.tsetsen.api.v1.CheckStatusResponse.Metrics\x1a\x8f\x01\n\x07Metrics\x12\x12\n\nqueue_time\x18\x01 \x01(\x05\x12\x17\n\x0fprocessing_time\x18\x02 \x01(\x05\x12\x12\n\ntotal_time\x18\x03 \x01(\x05\x12\x14\n\x0c\x61udio_length\x18\x04 \x01(\x02\x12\x14\n\x0c\x63redits_used\x18\x05 \x01(\x05\x12\x17\n\x0f\x63haracter_count\x18\x06 \x01(\x05\"X\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\x0e\n\nPROCESSING\x10\x02\x12\r\n\tCOMPLETED\x10\x03\x12\n\n\x06\x46\x41ILED\x10\x04\"(\n\x15GetUserBalanceRequest\x12\x0f\n\x07\x61pi_key\x18\x01 \x01(\t\")\n\x16GetUserBalanceResponse\x12\x0f\n\x07\x63redits\x18\x01 \x01(\x05\"f\n\x13StreamSpeechRequest\x12\x0f\n\x07\x61pi_key\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x10\n\x08voice_id\x18\x03 \x01(\t\x12\r\n\x05speed\x18\x04 \x01(\x02\x12\x0f\n\x07version\x18\x05 \x01(\t\"T\n\x14StreamSpeechResponse\x12\x13\n\x0b\x61udio_chunk\x18\x01 \x01(\x0c\x12\x10\n\x08is_final\x18\x02 \x01(\x08\x12\x15\n\rerror_message\x18\x03 \x01(\t2\xe2\x03\n\nTsetsenTTS\x12U\n\nListVoices\x12!.tsetsen.api.v1.ListVoicesRequest\x1a\".tsetsen.api.v1.ListVoicesResponse\"\x00\x12\x61\n\x0eGenerateSpeech\x12%.tsetsen.api.v1.GenerateSpeechRequest\x1a&.tsetsen.api.v1.GenerateSpeechResponse\"\x00\x12X\n\x0b\x43heckStatus\x12\".tsetsen.api.v1.CheckStatusRequest\x1a#.tsetsen.api.v1.CheckStatusResponse\"\x00\x12\x61\n\x0eGetUserBalance\x12%.tsetsen.api.v1.GetUserBalanceRequest\x1a&.tsetsen.api.v1.GetUserBalanceResponse\"\x00\x12]\n\x0cStreamSpeech\x12#.tsetsen.api.v1.StreamSpeechRequest\x1a$.tsetsen.api.v1.StreamSpeechResponse\"\x00\x30\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tsetsen_tts_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_LISTVOICESREQUEST']._serialized_start=37
  _globals['_LISTVOICESREQUEST']._serialized_end=110
  _globals['_VOICE']._serialized_start=113
  _globals['_VOICE']._serialized_end=287
  _globals['_VOICE_GENDER']._serialized_start=233
  _globals['_VOICE_GENDER']._serialized_end=287
  _globals['_LISTVOICESRESPONSE']._serialized_start=289
  _globals['_LISTVOICESRESPONSE']._serialized_end=348
  _globals['_GENERATESPEECHREQUEST']._serialized_start=350
  _globals['_GENERATESPEECHREQUEST']._serialized_end=454
  _globals['_GENERATESPEECHRESPONSE']._serialized_start=457
  _globals['_GENERATESPEECHRESPONSE']._serialized_end=654
  _globals['_GENERATESPEECHRESPONSE_STATUS']._serialized_start=566
  _globals['_GENERATESPEECHRESPONSE_STATUS']._serialized_end=654
  _globals['_CHECKSTATUSREQUEST']._serialized_start=656
  _globals['_CHECKSTATUSREQUEST']._serialized_end=713
  _globals['_CHECKSTATUSRESPONSE']._serialized_start=716
  _globals['_CHECKSTATUSRESPONSE']._serialized_end=1157
  _globals['_CHECKSTATUSRESPONSE_METRICS']._serialized_start=924
  _globals['_CHECKSTATUSRESPONSE_METRICS']._serialized_end=1067
  _globals['_CHECKSTATUSRESPONSE_STATUS']._serialized_start=566
  _globals['_CHECKSTATUSRESPONSE_STATUS']._serialized_end=654
  _globals['_GETUSERBALANCEREQUEST']._serialized_start=1159
  _globals['_GETUSERBALANCEREQUEST']._serialized_end=1199
  _globals['_GETUSERBALANCERESPONSE']._serialized_start=1201
  _globals['_GETUSERBALANCERESPONSE']._serialized_end=1242
  _globals['_STREAMSPEECHREQUEST']._serialized_start=1244
  _globals['_STREAMSPEECHREQUEST']._serialized_end=1346
  _globals['_STREAMSPEECHRESPONSE']._serialized_start=1348
  _globals['_STREAMSPEECHRESPONSE']._serialized_end=1432
  _globals['_TSETSENTTS']._serialized_start=1435
  _globals['_TSETSENTTS']._serialized_end=1917
# @@protoc_insertion_point(module_scope)
